@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Aloe - Cucumber runner for Python based on Lettuce and Nose
 # Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
@@ -36,7 +37,7 @@ from aloe.registry import (
     step,
 )
 
-world = threading.local()
+world = threading.local()  # pylint:disable=invalid-name
 
 
 def main(argv=None):  # pragma: no cover
