@@ -23,6 +23,7 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
+# pylint:disable=redefined-builtin
 from builtins import range
 from builtins import super
 from builtins import open
@@ -31,46 +32,52 @@ from builtins import dict
 from builtins import str
 from builtins import map
 from builtins import zip
+# pylint:enable=redefined-builtin
 from future import standard_library
 standard_library.install_aliases()
 
 import os
+
 from codecs import open
 from copy import deepcopy
 from collections import OrderedDict
 from warnings import warn
 
+import pyparsing
 from pyparsing import (CharsNotIn,
                        col,
                        Group,
                        Keyword,
-                       line,
                        lineEnd,
                        lineno,
                        OneOrMore,
                        Optional,
                        ParseException,
-                       pythonStyleComment,
+                       ParseResults,
                        QuotedString,  # function
                        quotedString,  # token
                        restOfLine,
                        stringEnd,
                        Suppress,
+                       Token,
                        Word,
                        ZeroOrMore)
 
-from fuzzywuzzy import fuzz
-
 from aloe import languages, strings
 from aloe.exceptions import LettuceSyntaxError, LettuceSyntaxWarning
 
+# Pyparsing has strange naming guidelines
+# pylint:disable=invalid-name,unused-argument
+
+# Pylint is thoroughly confused about members
+# pylint:disable=no-member
 
 # TODO: is this needed?
 memoizedproperty = property
 
 
-unicodePrintables = u''.join(chr(c) for c in range(65536)
-                             if not chr(c).isspace())
+unicodePrintables = ''.join(chr(c) for c in range(65536)
+                            if not chr(c).isspace())
 
 
 class ParseLocation(object):
@@ -108,6 +115,7 @@ class ParseLocation(object):
 
     @file.setter
     def file(self, value):
+        """Set the file."""
         self._file = value
 
 
@@ -118,7 +126,7 @@ class Node(object):
 
     def __init__(self, s, loc, tokens):
         self.described_at = ParseLocation(self, s, loc)
-        self.text = line(loc, s)
+        self.text = pyparsing.line(loc, s)
 
     def represented(self, indent=0, annotate=True):
         """
@@ -330,6 +338,7 @@ class TaggedBlock(Block):
 
     @property
     def tags(self):
+        """Tags for the scenario, feature, etc."""
         return self._tags
 
     def represented(self, indent=0, annotate=True):
@@ -352,56 +361,15 @@ class TaggedBlock(Block):
 
         return u' ' * indent + u'  '.join(u'@%s' % tag for tag in self.tags)
 
-    def matches_tags(self, tags):
-        """
-        Return true if the TaggedBlock contains all of the tags specified
-        by tags AND does not contain any of the excluded tags AND
-        matches any 'fuzzy' tags
-        """
-
-        our_tags = set(self.tags)
-
-        fuzzy_required_tags = set(tag[1:] for tag in tags
-                                  if tag.startswith('~'))
-        fuzzy_unwanted_tags = set(tag[2:] for tag in tags
-                                  if tag.startswith('-~'))
-        unwanted_tags = set(tag[1:] for tag in tags
-                            if tag.startswith('-'))
-        required_tags = set(
-            tag for tag in tags
-            if not tag.startswith('-') and not tag.startswith('~')
-        )
-
-        # at least one of the required tags should appear in ours tags (i.e.
-        # the intersection is not {})
-        # the unwanted tags should be a disjoint set (i.e. intersection is {})
-        if (required_tags and required_tags.isdisjoint(our_tags)) or \
-           not unwanted_tags.isdisjoint(our_tags):
-            # if either case isn't true, don't even attempt the fuzzy matching
-            return False
-
-        # apply fuzzy matches
-        #
-        # all required fuzzy tags must have an 80% match to at least
-        # one of our tags
-        fuzzy_matches = \
-            all(any(fuzz.ratio(tag, our_tag) > 80 for our_tag in our_tags)
-                for tag in fuzzy_required_tags)
-
-        # unwanted fuzzy tags must have a <= 80% match to all of our tags
-        fuzzy_unwanted = \
-            all(fuzz.ratio(tag, our_tag) <= 80
-                for tag in fuzzy_unwanted_tags
-                for our_tag in our_tags)
-
-        return fuzzy_matches and fuzzy_unwanted
-
 
 class Background(Block):
+    """Scenario background."""
     pass
 
 
 class Scenario(TaggedBlock):
+    """Scenario."""
+
     @classmethod
     def add_statements(cls, tokens):
         token = tokens[0]
@@ -559,15 +527,22 @@ class Description(Node):
 
     @memoizedproperty
     def max_length(self):
+        """
+        The maximum length of all description lines.
+        """
         try:
-            return max(strings.get_terminal_width(
-                self.represent_line(n, annotate=False))
-                for n, _ in enumerate(self.lines))
+            return max(
+                strings.get_terminal_width(
+                    self.represent_line(n, annotate=False))
+                for n, _ in enumerate(self.lines)
+            )
         except ValueError:
             return 0
 
 
 class Feature(TaggedBlock):
+    """Gherkin feature."""
+
     @classmethod
     def from_string(cls, string, **kwargs):
         """
@@ -644,6 +619,7 @@ class Feature(TaggedBlock):
             *[scenario.max_length for scenario in self.scenarios]
         )
 
+    # pylint:disable=arguments-differ
     def represented(self, indent=0, annotate=True, description=True):
         s = super().represented(indent=indent, annotate=annotate)
 
@@ -655,9 +631,6 @@ class Feature(TaggedBlock):
 
         return s
 
-    def represent_description(self, **kwargs):
-        return self.description_node.represented(**kwargs)
-
 
 def guess_language(string=None, filename=None):
     """
@@ -670,6 +643,9 @@ def guess_language(string=None, filename=None):
     phrase.
     """
 
+    # Default
+    code = 'en'
+
     LANG_PARSER = ZeroOrMore(
         Suppress('#') + (
             ((Suppress(Keyword('language')) + Suppress(':') +
@@ -687,18 +663,55 @@ def guess_language(string=None, filename=None):
         else:
             raise RuntimeError("Must pass string or filename")
 
-        code = tokens.language
-
-        if code != '':
-            return languages.Language(code=code)
+        if tokens.language != '':
+            code = tokens.language
 
     except ParseException:
-        # try English
         pass
 
-    return languages.English()
+    return languages.Language(code=code)
 
 
+class GherkinComment(Token):
+    """Matches a comment on an otherwise blank line."""
+
+    errmsg = "Expected a Gherkin comment."
+
+    def parseImpl(self, instring, loc, doActions=True):
+        """Check if the comment is on a line by itself."""
+
+        # TODO: Pyparsing calls this (via .ignore()) with loc pointing to the
+        # first non-whitespace character on a line, so a naive Regex with ^
+        # doesn't work (and Python doesn't support variable-length
+        # lookbehind).
+
+        line_start = instring.rfind('\n', 0, loc)
+        if line_start == -1:
+            line_start = 0
+        else:
+            line_start += 1
+
+        if instring[line_start:loc].strip() == '' and instring[loc] == '#':
+            # Return the found comment and its end position
+            line_end = instring.find('\n', loc)
+            if line_end == -1:
+                line_end = len(instring)
+
+            comment = instring[loc:line_end]
+
+            return (line_end, ParseResults([comment]))
+        else:
+            raise ParseException(instring, loc, self.errmsg, self)
+
+    def __str__(self):
+        return 'GherkinComment()'
+
+
+# TODO: This should be a class inheriting from aloe.languages.Language and
+# defining all the additional token types. Then the 'constructors' argument can
+# be replaced by subclassing (in aloe.testclass).
+# pylint:disable=too-complex,too-many-locals
+
 def parse(string=None,
           filename=None,
           token='FEATURE',
@@ -748,6 +761,7 @@ def parse(string=None,
     # Table cells need to be able to handle escaped tokens such as \| and \n
     #
     def handle_esc_char(tokens):
+        """Handle escaped tokens, such as \\| and \\n, in table cells."""
         token = tokens[0]
 
         if token == r'\|':
@@ -768,7 +782,7 @@ def parse(string=None,
     # and recombine the cell afterwards
     #
     CELL = OneOrMore(CharsNotIn('|\n\\') + Optional(ESC_CHAR))
-    CELL.setParseAction(lambda tokens: u''.join(tokens))
+    CELL.setParseAction(''.join)
 
     TABLE_ROW = Suppress('|') + OneOrMore(CELL + Suppress('|')) + EOL
     TABLE_ROW.setParseAction(lambda tokens: [v.strip() for v in tokens])
@@ -825,9 +839,8 @@ def parse(string=None,
 
     # A Step
     #
-    # Steps begin with a keyword such as Given, When, Then or And They can
-    # contain an optional inline comment, although it's possible to encapsulate
-    # it in a string. Finally they can contain a table or a multiline 'Python'
+    # Steps begin with a keyword such as Given, When, Then or And.
+    # After the step sentence they can contain a table or a multiline 'Python'
     # string.
     #
     # <variables> are not parsed as part of the grammar as it's not easy to
@@ -914,7 +927,7 @@ def parse(string=None,
         Optional(BACKGROUND('background')) +
         Group(OneOrMore(SCENARIO))('scenarios') +
         stringEnd)
-    FEATURE.ignore(pythonStyleComment)
+    FEATURE.ignore(GherkinComment())
     FEATURE.setParseAction(CONSTRUCTORS['feature'].add_blocks)
 
     #
